@@ -5,12 +5,16 @@
 
 # Third party imports
 from winpty.cywinpty import Agent
+from winpty.winpty_wrapper import PY2
+from winpty.ptyprocess import which
 import pytest
 
 
 # yapf: disable
 
-CMD = r'C:\windows\system32\cmd.exe'
+CMD = which('cmd')
+if PY2:
+    CMD = unicode(CMD)  # noqa
 
 
 @pytest.fixture(scope='module')
@@ -29,7 +33,14 @@ def test_agent_spawn():
 def test_agent_spawn_fail():
     agent = agent_fixture(80, 25)
     try:
-        agent.spawn('cmd.exe')
+        agent.spawn(CMD)
+    except RuntimeError:
+        pass
+
+
+def test_agent_spawn_size_fail():
+    try:
+        agent_fixture(80, -25)
     except RuntimeError:
         pass
 
@@ -38,3 +49,11 @@ def test_agent_resize():
     agent = agent_fixture(80, 25)
     agent.set_size(80, 70)
     del agent
+
+
+def test_agent_resize_fail():
+    agent = agent_fixture(80, 25)
+    try:
+        agent.set_size(-80, 70)
+    except RuntimeError:
+        pass
